@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
- 
+
 #if !defined (__CHAMPLAIN_GTK_CHAMPLAIN_GTK_H_INSIDE__) && !defined (CHAMPLAIN_GTK_COMPILATION)
 #error "Only <champlain/champlain.h> can be included directly."
 #endif
@@ -26,6 +26,8 @@
 #include <gtk/gtk.h>
 #include <champlain/champlain.h>
 
+G_BEGIN_DECLS
+
 #define GTK_TYPE_CHAMPLAIN_EMBED     (gtk_champlain_embed_get_type())
 #define GTK_CHAMPLAIN_EMBED(obj)     (G_TYPE_CHECK_INSTANCE_CAST((obj), GTK_TYPE_CHAMPLAIN_EMBED, GtkChamplainEmbed))
 #define GTK_CHAMPLAIN_EMBED_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST((klass),  GTK_TYPE_CHAMPLAIN_EMBED, GtkChamplainEmbedClass))
@@ -57,9 +59,6 @@ GType gtk_champlain_embed_get_type (void);
 GtkWidget *gtk_champlain_embed_new (void);
 ChamplainView *gtk_champlain_embed_get_view (GtkChamplainEmbed* embed);
 
-/* DEPRECATED API */
-GtkWidget *champlain_view_embed_new (ChamplainView *view) G_GNUC_DEPRECATED;
-ChamplainView *champlain_view_embed_get_view (GtkChamplainEmbed* embed) G_GNUC_DEPRECATED;
-void champlain_view_embed_set_view (GtkChamplainEmbed *embed, ChamplainView *view) G_GNUC_DEPRECATED;
+G_END_DECLS
 
 #endif
